import { type ButtonProps as BaseButtonProps } from '@restart/ui/Button';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import type { ButtonVariant } from './types';
export interface ButtonProps extends BaseButtonProps {
    /**
     * @default 'btn'
     */
    bsPrefix?: string | undefined;
    /**
     * Manually set the visual state of the button to `:active`
     */
    active?: boolean | undefined;
    /**
     * One or more button variant combinations
     *
     * buttons may be one of a variety of visual variants such as:
     *
     * `'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light', 'link'`
     *
     * as well as "outline" versions (prefixed by 'outline-*')
     *
     * `'outline-primary', 'outline-secondary', 'outline-success', 'outline-danger', 'outline-warning', 'outline-info', 'outline-dark', 'outline-light'`
     *
     * @type {'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'dark' | 'light' | 'link' | 'outline-primary' | 'outline-secondary' | 'outline-success' | 'outline-danger' | 'outline-warning' | 'outline-info' | 'outline-dark' | 'outline-light'}
     */
    variant?: ButtonVariant | undefined;
    /**
     * Specifies a large or small button.
     *
     * @type {'sm' | 'lg'}
     */
    size?: 'sm' | 'lg' | undefined;
    /**
     * Disables the Button, preventing mouse events,
     * even if the underlying component is an `<a>` element
     */
    disabled?: boolean | undefined;
    /**
     * Providing a `href` will render an `<a>` element, _styled_ as a button.
     */
    href?: string | undefined;
}
export type CommonButtonProps = 'href' | 'size' | 'variant' | 'disabled';
declare const Button: DynamicRefForwardingComponent<'button', ButtonProps>;
export default Button;
