import React from 'react';
import Transition from 'react-transition-group/Transition';
import type { TransitionCallbacks } from './types';
type Dimension = 'height' | 'width';
export interface CollapseProps extends TransitionCallbacks, Pick<React.HTMLAttributes<HTMLElement>, 'className' | 'role'> {
    /**
     * Show the component; triggers the expand or collapse animation
     */
    in?: boolean | undefined;
    /**
     * Wait until the first "enter" transition to mount the component (add it to the DOM)
     */
    mountOnEnter?: boolean | undefined;
    /**
     * Unmount the component (remove it from the DOM) when it is collapsed
     */
    unmountOnExit?: boolean | undefined;
    /**
     * Run the expand animation when the component mounts, if it is initially shown
     */
    appear?: boolean | undefined;
    /**
     * Duration of the collapse animation in milliseconds, to ensure that
     * finishing callbacks are fired even if the original browser transition end
     * events are canceled
     */
    timeout?: number | undefined;
    /**
     * The dimension used when collapsing, or a function that returns the
     * dimension
     *
     * @type {'height' | 'width' | (() => 'height' | 'width')  | undefined}
     */
    dimension?: Dimension | (() => Dimension) | undefined;
    /**
     * Function that returns the height or width of the animating DOM node
     *
     * Allows for providing some custom logic for how much the Collapse component
     * should animate in its specified dimension. Called with the current
     * dimension prop value and the DOM node.
     *
     * @type {((dimension: Dimension, element: HTMLElement) => number) | undefined}
     * @default element.offsetWidth | element.offsetHeight
     */
    getDimensionValue?: ((dimension: Dimension, element: HTMLElement) => number) | undefined;
    /**
     * You must provide a single JSX child element to this component and that element cannot be a \<React.Fragment\>
     */
    children: React.ReactElement;
}
declare const Collapse: React.ForwardRefExoticComponent<CollapseProps & React.RefAttributes<Transition<any>>>;
export default Collapse;
