import * as React from 'react';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
type FormControlElement = HTMLInputElement | HTMLTextAreaElement;
export interface FormControlProps extends Omit<React.InputHTMLAttributes<FormControlElement>, 'size'> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'form-control'
     */
    bsPrefix?: string | undefined;
    /**
     * The size attribute of the underlying HTML element.
     * Specifies the visible width in characters if `as` is `'input'`.
     */
    htmlSize?: number | undefined;
    /**
     * Input size variants
     */
    size?: 'sm' | 'lg' | undefined;
    /**
     * Render the input as plain text. Generally used along side `readOnly`.
     */
    plaintext?: boolean | undefined;
    /**
     * Make the control readonly
     */
    readOnly?: boolean | undefined;
    /**
     * Make the control disabled
     */
    disabled?: boolean | undefined;
    /**
     * The `value` attribute of underlying input
     *
     * @controllable onChange
     * */
    value?: string | string[] | number | undefined;
    /**
     * A callback fired when the `value` prop changes
     */
    onChange?: React.ChangeEventHandler<FormControlElement> | undefined;
    /**
     * The HTML input `type`, which is only relevant if `as` is `'input'` (the default).
     */
    type?: string | undefined;
    /**
     * Uses `controlId` from `<FormGroup>` if not explicitly specified.
     */
    id?: string | undefined;
    /**
     * Add "valid" validation styles to the control
     */
    isValid?: boolean | undefined;
    /**
     * Add "invalid" validation styles to the control and accompanying label
     */
    isInvalid?: boolean | undefined;
}
declare const _default: DynamicRefForwardingComponent<"input", FormControlProps> & {
    Feedback: DynamicRefForwardingComponent<"div", import("./Feedback").FeedbackProps>;
};
export default _default;
