import * as React from 'react';
import { type ModalHandle } from '@restart/ui/Modal';
import type { BaseModalProps } from './types';
export interface ModalProps extends BaseModalProps {
    /**
     * @default 'modal'
     */
    bsPrefix?: string | undefined;
    /**
     * Render a large, extra large or small modal.
     * When not provided, the modal is rendered with medium (default) size.
     */
    size?: 'sm' | 'lg' | 'xl' | undefined;
    /**
     * Renders a fullscreen modal. Specifying a breakpoint will render the modal
     * as fullscreen __below__ the breakpoint size.
     */
    fullscreen?: true | string | 'sm-down' | 'md-down' | 'lg-down' | 'xl-down' | 'xxl-down' | undefined;
    /**
     * vertically center the Dialog in the window
     */
    centered?: boolean | undefined;
    /**
     * Add an optional extra class name to .modal-backdrop
     * It could end up looking like class="modal-backdrop foo-modal-backdrop in".
     */
    backdropClassName?: string;
    /**
     * Open and close the Modal with a slide and fade animation.
     */
    animation?: boolean | undefined;
    /**
     * A css class to apply to the Modal dialog DOM node.
     */
    dialogClassName?: string | undefined;
    /**
     * Add an optional extra class name to .modal-content
     */
    contentClassName?: string | undefined;
    /**
     * A Component type that provides the modal content Markup. This is a useful
     * prop when you want to use your own styles and markup to create a custom
     * modal component.
     *
     * @default ModalDialog
     */
    dialogAs?: React.ElementType | undefined;
    /**
     * Allows scrolling the `<Modal.Body>` instead of the entire Modal when overflowing.
     */
    scrollable?: boolean | undefined;
    [other: string]: any;
}
declare const _default: React.ForwardRefExoticComponent<Omit<ModalProps, "ref"> & React.RefAttributes<ModalHandle>> & {
    Body: import("@restart/ui/types").DynamicRefForwardingComponent<"div", import("./ModalBody").ModalBodyProps>;
    Header: React.ForwardRefExoticComponent<import("./ModalHeader").ModalHeaderProps & React.RefAttributes<HTMLDivElement>>;
    Title: import("@restart/ui/types").DynamicRefForwardingComponent<"span", import("./ModalTitle").ModalTitleProps>;
    Footer: import("@restart/ui/types").DynamicRefForwardingComponent<"div", import("./ModalFooter").ModalFooterProps>;
    Dialog: React.ForwardRefExoticComponent<import("./ModalDialog").ModalDialogProps & React.RefAttributes<HTMLDivElement>>;
    TRANSITION_DURATION: number;
    BACKDROP_TRANSITION_DURATION: number;
};
export default _default;
