import * as React from 'react';
import { DynamicRefForwardingComponent, EventKey } from '@restart/ui/types';
import type { BaseNavProps } from './types';
export interface NavProps extends BaseNavProps {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'nav'
     */
    bsPrefix?: string | undefined;
    /**
     * The visual variant of the nav items.
     */
    variant?: 'tabs' | 'pills' | 'underline' | string | undefined;
    /**
     * The default active key that is selected on start.
     */
    defaultActiveKey?: EventKey | undefined;
    /**
     * Have all `NavItem`s proportionately fill all available width.
     */
    fill?: boolean | undefined;
    /**
     * Have all `NavItem`s evenly fill all available width.
     */
    justify?: boolean | undefined;
    /**
     * Apply styling an alignment for use in a Navbar. This prop will be set
     * automatically when the Nav is used inside a Navbar.
     */
    navbar?: boolean | undefined;
    /**
     * Enable vertical scrolling within the toggleable contents of a collapsed Navbar.
     */
    navbarScroll?: boolean | undefined;
    /**
     * ARIA role for the Nav, in the context of a TabContainer, the default will
     * be set to "tablist", but can be overridden by the Nav when set explicitly.
     *
     * When the role is "tablist", NavLink focus is managed according to
     * the ARIA authoring practices for tabs:
     * https://www.w3.org/TR/2013/WD-wai-aria-practices-20130307/#tabpanel
     */
    role?: string | undefined;
}
declare const _default: DynamicRefForwardingComponent<"div", NavProps> & {
    Item: DynamicRefForwardingComponent<"div", import("./NavItem").NavItemProps>;
    Link: DynamicRefForwardingComponent<"a", import("./NavLink").NavLinkProps>;
};
export default _default;
