import * as React from 'react';
import { DynamicRefForwardingComponent, EventKey } from '@restart/ui/types';
import type { BaseNavItemProps } from './types';
export interface NavLinkProps extends BaseNavItemProps {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'nav-link'
     */
    bsPrefix?: string | undefined;
    /**
     * The ARIA role for the `NavLink`, In the context of a 'tablist' parent Nav,
     * the role defaults to 'tab'
     * */
    role?: string | undefined;
    /**
     * The HTML href attribute for the `NavLink`. Used as the unique identifier
     * for the `NavLink` if an `eventKey` is not provided.
     */
    href?: string | undefined;
    /**
     * Uniquely identifies the `NavItem` amongst its siblings,
     * used to determine and control the active state of the parent `Nav`
     * as well as onSelect behavior of a parent `Navbar`.
     */
    eventKey?: EventKey | undefined;
    /**
     * Whether the link is disabled or not.
     */
    disabled?: boolean | undefined;
}
declare const NavLink: DynamicRefForwardingComponent<'a', NavLinkProps>;
export default NavLink;
