import * as React from 'react';
import { OverlayArrowProps } from '@restart/ui/Overlay';
import type { TransitionType } from './helpers';
import type { BaseOverlayProps, Placement, PopperRef, RootCloseEvent } from './types';
export interface OverlayInjectedProps {
    ref: React.RefCallback<HTMLElement>;
    style: React.CSSProperties;
    'aria-labelledby'?: string;
    arrowProps: Partial<OverlayArrowProps>;
    show: boolean;
    placement: Placement | undefined;
    popper: PopperRef;
    hasDoneInitialMeasure?: boolean;
    [prop: string]: any;
}
export type OverlayChildren = React.ReactElement<OverlayInjectedProps> | ((injected: OverlayInjectedProps) => React.ReactNode);
export interface OverlayProps extends BaseOverlayProps {
    /**
     * A component instance, DOM node, or function that returns either.
     */
    children: OverlayChildren;
    /**
     * Animate the entering and exiting of the Overlay. `true` will use the `<Fade>` transition,
     * or a custom react-transition-group `<Transition>` component can be provided.
     *
     * @default Fade
     */
    transition?: TransitionType | undefined;
    /**
     * The placement of the Overlay in relation to it's `target`.
     *
     * @type {Placement | undefined}
     */
    placement?: Placement | undefined;
    /**
     * Specify event for triggering a "root close" toggle.
     */
    rootCloseEvent?: RootCloseEvent | undefined;
}
declare const Overlay: React.ForwardRefExoticComponent<OverlayProps & React.RefAttributes<HTMLElement>>;
export default Overlay;
