import * as React from 'react';
import { type OverlayChildren, type OverlayProps } from './Overlay';
import type { Placement } from './types';
export type OverlayTriggerType = 'hover' | 'click' | 'focus';
export type OverlayDelay = number | {
    show: number;
    hide: number;
};
export type OverlayInjectedProps = {
    onFocus?: (...args: any[]) => any;
};
export type OverlayTriggerRenderProps = OverlayInjectedProps & {
    ref: React.Ref<any>;
};
export interface OverlayTriggerProps extends Omit<OverlayProps, 'children' | 'target' | 'onHide'> {
    children: React.ReactElement | ((props: OverlayTriggerRenderProps) => React.ReactNode);
    /**
     * Specify which action or actions trigger Overlay visibility
     *
     * The `click` trigger ignores the configured `delay`.
     */
    trigger?: OverlayTriggerType | OverlayTriggerType[] | undefined;
    /**
     * A millisecond delay amount to show and hide the Overlay once triggered
     */
    delay?: OverlayDelay | undefined;
    /**
     * The visibility of the Overlay. `show` is a _controlled_ prop so should be paired
     * with `onToggle` to avoid breaking user interactions.
     *
     * Manually toggling `show` does **not** wait for `delay` to change the visibility.
     *
     * @controllable onToggle
     */
    show?: boolean | undefined;
    /**
     * The initial visibility state of the Overlay.
     */
    defaultShow?: boolean | undefined;
    /**
     * A callback that fires when the user triggers a change in tooltip visibility.
     *
     * `onToggle` is called with the desired next `show`, and generally should be passed
     * back to the `show` prop. `onToggle` fires _after_ the configured `delay`
     *
     * @type {((nextShow: boolean) => void) | undefined}
     * @controllable `show`
     */
    onToggle?: ((nextShow: boolean) => void) | undefined;
    /**
      The initial flip state of the Overlay. If `placement` is specified and is anything
      other than "auto", this prop will default to `false`, otherwise the default is `true`.
     */
    flip?: boolean | undefined;
    /**
     * An element or text to overlay next to the target.
     *
     * @type {React.ReactElement<OverlayInjectedProps> | ((injected: OverlayInjectedProps) => React.ReactNode)}
     */
    overlay: OverlayChildren;
    /**
     * The placement of the Overlay in relation to it's `target`.
     */
    placement?: Placement | undefined;
}
declare const OverlayTrigger: React.FC<OverlayTriggerProps>;
export default OverlayTrigger;
