import * as React from 'react';
import type { DynamicRefForwardingComponent, EventKey } from '@restart/ui/types';
import type { TransitionType } from './helpers';
import type { TransitionCallbacks } from './types';
export interface TabPaneProps extends TransitionCallbacks, React.HTMLAttributes<HTMLElement> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'tab-pane'
     */
    bsPrefix?: string | undefined;
    /**
     * A key that associates the `TabPane` with it's controlling `NavLink`.
     */
    eventKey?: EventKey | undefined;
    /**
     * Toggles the active state of the TabPane, this is generally controlled by a
     * TabContainer.
     */
    active?: boolean | undefined;
    /**
     * Use animation when showing or hiding `<TabPane>`s. Defaults to `<Fade>`
     * animation, else use `false` to disable or a react-transition-group
     * `<Transition/>` component.
     */
    transition?: TransitionType | undefined;
    /**
     * Wait until the first "enter" transition to mount the tab (add it to the DOM)
     */
    mountOnEnter?: boolean | undefined;
    /**
     * Unmount the tab (remove it from the DOM) when it is no longer visible
     */
    unmountOnExit?: boolean | undefined;
}
declare const TabPane: DynamicRefForwardingComponent<'div', TabPaneProps>;
export default TabPane;
