import * as React from 'react';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import { type ButtonGroupProps } from './ButtonGroup';
type BaseToggleButtonProps = Omit<ButtonGroupProps, 'toggle' | 'defaultValue' | 'onChange'>;
export interface ToggleButtonRadioProps<T> extends BaseToggleButtonProps {
    /**
     * The input `type` of the rendered buttons, determines the toggle behavior
     * of the buttons
     */
    type?: 'radio';
    /**
     * An HTML `<input>` name for each child button.
     *
     * __Required if `type` is set to `'radio'`__
     */
    name: string;
    /**
     * The value, or array of values, of the active (pressed) buttons
     *
     * @controllable onChange
     */
    value?: T;
    /**
     * The default value, or array of values, of the active (pressed) buttons
     */
    defaultValue?: T;
    /**
     * Callback fired when a button is pressed, depending on whether the `type`
     * is `'radio'` or `'checkbox'`, `onChange` will be called with the value or
     * array of active values
     *
     * @controllable value
     */
    onChange?: (value: T, event: any) => void;
}
export interface ToggleButtonCheckboxProps<T> extends BaseToggleButtonProps {
    /**
     * The input `type` of the rendered buttons, determines the toggle behavior
     * of the buttons
     */
    type: 'checkbox';
    /**
     * An HTML `<input>` name for each child button.
     *
     * __Required if `type` is set to `'radio'`__
     */
    name?: string;
    /**
     * The value, or array of values, of the active (pressed) buttons
     *
     * @controllable onChange
     */
    value?: T[];
    /**
     * The default value, or array of values, of the active (pressed) buttons
     */
    defaultValue?: T[];
    /**
     * Callback fired when a button is pressed, depending on whether the `type`
     * is `'radio'` or `'checkbox'`, `onChange` will be called with the value or
     * array of active values
     *
     * @controllable value
     */
    onChange?: (value: T[]) => void;
}
export type ToggleButtonGroupProps<T> = ToggleButtonRadioProps<T> | ToggleButtonCheckboxProps<T>;
declare const _default: DynamicRefForwardingComponent<"a", ToggleButtonGroupProps<any>> & {
    Button: React.ForwardRefExoticComponent<import("./ToggleButton").ToggleButtonProps & React.RefAttributes<HTMLLabelElement>>;
};
export default _default;
