import * as React from 'react';
import { OverlayArrowProps } from '@restart/ui/Overlay';
import type { Placement, PopperRef } from './types';
export interface TooltipProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
     * @default 'tooltip'
     */
    bsPrefix?: string | undefined;
    /**
     * Sets the direction the Tooltip is positioned towards.
     *
     * > This is generally provided by the `Overlay` component positioning the tooltip
     *
     * @type {Placement | undefined}
     */
    placement?: Placement | undefined;
    /**
     * An Overlay injected set of props for positioning the tooltip arrow.
     *
     * > This is generally provided by the `Overlay` component positioning the tooltip
     *
     * @type {{ ref: ReactRef, style: Object }}
     */
    arrowProps?: Partial<OverlayArrowProps> | undefined;
    /**
     * @private
     */
    show?: boolean;
    /**
     * @private
     */
    popper?: PopperRef | undefined;
    /**
     * Whether or not Popper has done its initial measurement and positioning.
     *
     * @private
     */
    hasDoneInitialMeasure?: boolean | undefined;
}
declare const _default: React.ForwardRefExoticComponent<TooltipProps & React.RefAttributes<HTMLDivElement>> & {
    TOOLTIP_OFFSET: number[];
};
export default _default;
