import * as React from 'react';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import { type AccordionSelectCallback, type AccordionEventKey } from './AccordionContext';
export interface AccordionProps extends Omit<React.HTMLAttributes<HTMLElement>, 'onSelect'> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'accordion'
     */
    bsPrefix?: string | undefined;
    /**
     * The current active key that corresponds to the currently expanded card.
     */
    activeKey?: AccordionEventKey | undefined;
    /**
     * The default active key that is expanded on start
     */
    defaultActiveKey?: AccordionEventKey | undefined;
    /**
     * Callback fired when the active item changes.
     *
     * ```js
     * (eventKey: string | string[] | null, event: Object) => void
     * ```
     *
     * @controllable activeIndex
     */
    onSelect?: AccordionSelectCallback | undefined;
    /**
     * Renders accordion edge-to-edge with its parent container.
     */
    flush?: boolean | undefined;
    /**
     * Allow accordion items to stay open when another item is opened.
     */
    alwaysOpen?: boolean | undefined;
}
declare const _default: DynamicRefForwardingComponent<"div", AccordionProps> & {
    Button: DynamicRefForwardingComponent<"div", import("./AccordionButton").AccordionButtonProps>;
    Collapse: DynamicRefForwardingComponent<"div", import("./AccordionCollapse").AccordionCollapseProps>;
    Item: DynamicRefForwardingComponent<"div", import("./AccordionItem").AccordionItemProps>;
    Header: DynamicRefForwardingComponent<"h2", import("./AccordionHeader").AccordionHeaderProps>;
    Body: DynamicRefForwardingComponent<"div", import("./AccordionBody").AccordionBodyProps>;
};
export default _default;
