import * as React from 'react';
import { type CloseButtonVariant } from './CloseButton';
import type { Variant } from './types';
import type { TransitionType } from './helpers';
export interface AlertProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
     * @default 'alert'
     */
    bsPrefix?: string | undefined;
    /**
     * The Alert visual variant.
     *
     * @type {'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'dark' | 'light' | undefined}
     */
    variant?: Variant | undefined;
    /**
     * Renders a properly aligned dismiss button, as well as
     * adding extra horizontal padding to the Alert.
     */
    dismissible?: boolean | undefined;
    /**
     * Controls the visual state of the Alert.
     *
     * @controllable onClose
     */
    show?: boolean | undefined;
    /**
     * Default show state of the Alert.
     */
    defaultShow?: boolean | undefined;
    /**
     * Callback fired when alert is closed.
     *
     * @type {((show: boolean, event: any) => void) | undefined}
     * @controllable show
     */
    onClose?: ((show: boolean, event: any) => void) | undefined;
    /**
     * Sets the text for alert close button.
     */
    closeLabel?: string | undefined;
    /**
     * Sets the variant for close button.
     */
    closeVariant?: CloseButtonVariant | undefined;
    /**
     * Animate the alert dismissal. Defaults to using `<Fade>` animation or use
     * `false` to disable. A custom `react-transition-group` Transition can also
     * be provided.
     */
    transition?: TransitionType | undefined;
}
declare const _default: React.ForwardRefExoticComponent<AlertProps & React.RefAttributes<HTMLDivElement>> & {
    Link: import("@restart/ui/types").DynamicRefForwardingComponent<"a", import("./AlertLink").AlertLinkProps>;
    Heading: import("@restart/ui/types").DynamicRefForwardingComponent<"div", import("./AlertHeading").AlertHeadingProps>;
};
export default _default;
