import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import * as React from 'react';
export type CarouselVariant = 'dark' | string;
export interface CarouselRef {
    element?: HTMLElement | null;
    prev: (e?: React.SyntheticEvent) => void;
    next: (e?: React.SyntheticEvent) => void;
}
export interface CarouselProps extends Omit<React.HTMLAttributes<HTMLElement>, 'onSelect'> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'carousel'
     */
    bsPrefix?: string | undefined;
    /**
     * Enables animation on the Carousel as it transitions between slides.
     */
    slide?: boolean | undefined;
    /**
     * Animates slides with a crossfade animation instead of the default slide animation.
     */
    fade?: boolean | undefined;
    /**
     * Show the Carousel previous and next arrows for changing the current slide.
     */
    controls?: boolean | undefined;
    /**
     * Show a set of slide position indicators.
     */
    indicators?: boolean | undefined;
    /**
     * An array of labels for the indicators. Defaults to "Slide #" if not provided.
     */
    indicatorLabels?: string[] | undefined;
    /**
     * Controls the current visible slide.
     *
     * @controllable onSelect
     */
    activeIndex?: number | undefined;
    /**
     * The default active index that is shown when the component is first rendered.
     */
    defaultActiveIndex?: number | undefined;
    /**
     * Callback fired when the active item changes.
     *
     * ```js
     * (eventKey: number, event: Object | null) => void
     * ```
     *
     * @type {((eventKey: number, event: Record<string, unknown> | null) => void) | undefined}
     * @controllable activeIndex
     */
    onSelect?: ((eventKey: number, event: Record<string, unknown> | null) => void) | undefined;
    /**
     * Callback fired when a slide transition starts.
     *
     * ```js
     * (eventKey: number, direction: 'left' | 'right') => void
     * ```
     *
     * @type {((eventKey: number, direction: 'left' | 'right') => void) | undefined}
     */
    onSlide?: ((eventKey: number, direction: 'start' | 'end') => void) | undefined;
    /**
     * Callback fired when a slide transition ends.
     *
     * ```js
     * (eventKey: number, direction: 'left' | 'right') => void
     * ```
     *
     * @type {((eventKey: number, direction: 'left' | 'right') => void) | undefined}
     */
    onSlid?: ((eventKey: number, direction: 'start' | 'end') => void) | undefined;
    /**
     * The amount of time to delay between automatically cycling an item. If `null`, carousel will not automatically cycle.
     */
    interval?: number | null | undefined;
    /**
     * Whether the carousel should react to keyboard events.
     */
    keyboard?: boolean | undefined;
    /**
     * If set to `"hover"`, pauses the cycling of the carousel on `mouseenter` and resumes the cycling of the carousel on
     * `mouseleave`. If set to `false`, hovering over the carousel won't pause it.
     *
     * On touch-enabled devices, when set to `"hover"`, cycling will pause on `touchend` (once the user finished interacting
     * with the carousel) for two intervals, before automatically resuming. Note that this is in addition to the above mouse
     * behavior.
     */
    pause?: 'hover' | false | undefined;
    /**
     * Whether the carousel should cycle continuously or have hard stops.
     */
    wrap?: boolean | undefined;
    /**
     * Whether the carousel should support left/right swipe interactions on touchscreen devices.
     */
    touch?: boolean | undefined;
    /**
     * Override the default button icon for the "previous" control.
     */
    prevIcon?: React.ReactNode | undefined;
    /**
     * Label shown to screen readers only, can be used to show the previous element in the carousel.
     * Set to null to deactivate.
     */
    prevLabel?: React.ReactNode | undefined;
    /**
     * Override the default button icon for the "next" control
     */
    nextIcon?: React.ReactNode | undefined;
    /**
     * Label shown to screen readers only, can be used to show the next element in the carousel.
     * Set to null to deactivate.
     */
    nextLabel?: React.ReactNode | undefined;
    /**
     * Color variant that controls the colors of the controls, indicators
     * and captions.
     */
    variant?: CarouselVariant | undefined;
    /**
     * Carousel ref.
     */
    ref?: React.Ref<CarouselRef> | undefined;
}
declare const _default: DynamicRefForwardingComponent<"div", CarouselProps> & {
    Caption: DynamicRefForwardingComponent<"div", import("./CarouselCaption").CarouselCaptionProps>;
    Item: DynamicRefForwardingComponent<"div", import("./CarouselItem").CarouselItemProps>;
};
export default _default;
