import * as React from 'react';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import { type FeedbackType } from './Feedback';
export type FormCheckType = 'checkbox' | 'radio' | 'switch';
export interface FormCheckProps extends React.InputHTMLAttributes<HTMLInputElement> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'form-check'
     */
    bsPrefix?: string | undefined;
    /**
     * bsPrefix override for the base switch class.
     *
     * @default 'form-switch'
     */
    bsSwitchPrefix?: string | undefined;
    /**
     * A HTML id attribute, necessary for proper form accessibility.
     * An id is recommended for allowing label clicks to toggle the check control.
     *
     * This is **required** when `type="switch"` due to how they are rendered.
     */
    id?: string | undefined;
    /**
     * Provide a function child to manually handle the layout of the FormCheck's inner components.
     *
     * ```jsx
     * <FormCheck>
     *   <FormCheck.Input isInvalid type={radio} />
     *   <FormCheck.Label>Allow us to contact you?</FormCheck.Label>
     *   <Feedback type="invalid">Yo this is required</Feedback>
     * </FormCheck>
     * ```
     */
    children?: React.ReactNode | undefined;
    /**
     * Groups controls horizontally with other `FormCheck`s.
     */
    inline?: boolean | undefined;
    /**
     * Put your checkboxes, radios, and switches on the opposite side.
     */
    reverse?: boolean | undefined;
    /**
     * Disables the control.
     */
    disabled?: boolean | undefined;
    /**
     * `title` attribute for the underlying `FormCheckLabel`.
     */
    title?: string | undefined;
    /**
     * Label for the control.
     */
    label?: React.ReactNode | undefined;
    /**
     * The type of checkable.
     */
    type?: FormCheckType | undefined;
    /**
     * Manually style the input as valid
     */
    isValid?: boolean | undefined;
    /**
     * Manually style the input as invalid
     */
    isInvalid?: boolean;
    /**
     * Display feedback as a tooltip.
     */
    feedbackTooltip?: boolean | undefined;
    /**
     * A message to display when the input is in a validation state
     */
    feedback?: React.ReactNode | undefined;
    /**
     * Specify whether the feedback is for valid or invalid fields
     */
    feedbackType?: FeedbackType | undefined;
}
declare const _default: DynamicRefForwardingComponent<"input", FormCheckProps> & {
    Input: DynamicRefForwardingComponent<"input", import("./FormCheckInput").FormCheckInputProps>;
    Label: React.ForwardRefExoticComponent<import("./FormCheckLabel").FormCheckLabelProps & React.RefAttributes<HTMLLabelElement>>;
};
export default _default;
