import * as React from 'react';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import { type ColProps } from './Col';
interface FormLabelBaseProps extends React.HTMLAttributes<HTMLElement> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'form-label'
     */
    bsPrefix?: string | undefined;
    /**
     * Uses `controlId` from `<FormGroup>` if not explicitly specified.
     */
    htmlFor?: string | undefined;
    /**
     * Hides the label visually while still allowing it to be
     * read by assistive technologies.
     */
    visuallyHidden?: boolean | undefined;
}
export interface FormLabelOwnProps extends FormLabelBaseProps {
    /**
     * Renders the FormLabel as a `<Col>` component (accepting all the same props),
     * as well as adding additional styling for horizontal forms.
     */
    column?: false;
}
export interface FormLabelWithColProps extends FormLabelBaseProps, ColProps {
    /**
     * Renders the FormLabel as a `<Col>` component (accepting all the same props),
     * as well as adding additional styling for horizontal forms.
     */
    column: true | 'sm' | 'lg';
}
export type FormLabelProps = FormLabelWithColProps | FormLabelOwnProps;
declare const FormLabel: DynamicRefForwardingComponent<'label', FormLabelProps>;
export default FormLabel;
