import * as React from 'react';
import type { DynamicRefForwardingComponent } from '@restart/ui/types';
import type { BaseNavItemProps, Variant } from './types';
export interface ListGroupItemProps extends BaseNavItemProps {
    /**
     * You can use a custom element type for this component. For none `action` items, items render as `li`.
     * For actions the default is an anchor or button element depending on whether a `href` is provided.
     *
     * @default 'div' | 'a' | 'button'
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'list-group-item'
     */
    bsPrefix?: string | undefined;
    /**
     * Marks a ListGroupItem as actionable, applying additional hover, active and disabled styles
     * for links and buttons.
     */
    action?: boolean | undefined;
    /**
     * A callback function for when this component is clicked.
     */
    onClick?: React.MouseEventHandler;
    /**
     * Sets contextual classes for list item.
     *
     * @type {'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'light' | 'dark' | undefined}
     */
    variant?: Variant | undefined;
    /**
     * Providing a `href` and setting `action` to `true`, it will render the ListGroup.Item as
     * an `<a>` element (unless `as` is provided).
     */
    href?: string | undefined;
}
declare const ListGroupItem: DynamicRefForwardingComponent<'a', ListGroupItemProps>;
export default ListGroupItem;
