import * as React from 'react';
import { OverlayArrowProps } from '@restart/ui/Overlay';
import type { Placement, PopperRef } from './types';
export interface PopoverProps extends React.HTMLAttributes<HTMLDivElement> {
    /**
     * @default 'popover'
     */
    bsPrefix?: string | undefined;
    /**
     * Sets the direction the Popover is positioned towards.
     *
     * > This is generally provided by the `Overlay` component positioning the popover
     *
     * @type {Placement | undefined}
     */
    placement?: Placement | undefined;
    /**
     * An Overlay injected set of props for positioning the popover arrow.
     *
     * > This is generally provided by the `Overlay` component positioning the popover
     */
    arrowProps?: Partial<OverlayArrowProps> | undefined;
    /**
     * When this prop is set, it creates a Popover with a Popover.Body inside
     * passing the children directly to it
     */
    body?: boolean | undefined;
    /**
     * @private
     */
    popper?: PopperRef | undefined;
    /**
     * @private
     */
    show?: boolean | undefined;
    /**
     * Whether or not Popper has done its initial measurement and positioning.
     *
     * @private
     */
    hasDoneInitialMeasure?: boolean | undefined;
}
declare const _default: React.ForwardRefExoticComponent<PopoverProps & React.RefAttributes<HTMLDivElement>> & {
    Header: import("@restart/ui/types").DynamicRefForwardingComponent<"div", import("./PopoverHeader").PopoverHeaderProps>;
    Body: import("@restart/ui/types").DynamicRefForwardingComponent<"div", import("./PopoverBody").PopoverBodyProps>;
    POPPER_OFFSET: readonly [0, 8];
};
export default _default;
