import * as React from 'react';
import { DynamicRefForwardingComponent } from '@restart/ui/types';
import type { GapValue } from './types';
import { type ResponsiveUtilityValue } from './createUtilityClasses';
export type StackDirection = 'horizontal' | 'vertical';
export interface StackProps extends React.HTMLAttributes<HTMLElement> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * Change the underlying component CSS base class name and modifier class names prefix.
     * **This is an escape hatch** for working with heavily customized bootstrap css.
     *
     * Defaults to `hstack` if direction is `horizontal` or `vstack` if direction
     * is `vertical`.
     *
     * @default 'hstack | vstack'
     */
    bsPrefix?: string | undefined;
    /**
     * Flex direction.
     */
    direction?: StackDirection | undefined;
    /**
     * Sets the spacing between each item. Valid values are `0-5`.
     */
    gap?: ResponsiveUtilityValue<GapValue> | undefined;
}
declare const Stack: DynamicRefForwardingComponent<'span', StackProps>;
export default Stack;
