import * as React from 'react';
import type { DynamicRefForwardingComponent, TransitionComponent } from '@restart/ui/types';
import type { TransitionCallbacks, Variant } from './types';
export interface ToastProps extends TransitionCallbacks, React.HTMLAttributes<HTMLElement> {
    /**
     * Element used to render the component.
     */
    as?: React.ElementType | undefined;
    /**
     * @default 'toast'
     */
    bsPrefix?: string | undefined;
    /**
     * Apply a CSS fade transition to the toast
     */
    animation?: boolean | undefined;
    /**
     * Auto hide the toast
     */
    autohide?: boolean | undefined;
    /**
     * Delay hiding the toast (ms)
     */
    delay?: number | undefined;
    /**
     * A Callback fired when the close button is clicked.
     *
     * @type {((e?: React.MouseEvent | React.KeyboardEvent) => void) | undefined}
     */
    onClose?: ((e?: React.MouseEvent | React.KeyboardEvent) => void) | undefined;
    /**
     * When `true` The toast will show itself.
     */
    show?: boolean | undefined;
    /**
     * A `react-transition-group` Transition component used to animate the Toast on dismissal.
     *
     * @default ToastFade
     */
    transition?: TransitionComponent | undefined;
    /**
     * Sets Toast background
     *
     * @type {'primary' | 'secondary' | 'success' |'danger' | 'warning' | 'info' | 'dark' | 'light' | undefined}
     */
    bg?: Variant | undefined;
}
declare const _default: DynamicRefForwardingComponent<"div", ToastProps> & {
    Body: DynamicRefForwardingComponent<"div", import("./ToastBody").ToastBodyProps>;
    Header: React.ForwardRefExoticComponent<import("./ToastHeader").ToastHeaderProps & React.RefAttributes<HTMLDivElement>>;
};
export default _default;
